.navbar-nav > .user-menu > .dropdown-menu > .user-body {
    padding: 10px;
}

.navbar-nav > .user-menu > .dropdown-menu > .user-body a {
    color: var(--app-primary-color) !important;
    background-color: transparent !important;
}

.navbar-nav > .user-menu > .dropdown-menu > .user-body a:hover {
    color: var(--app-white-color) !important;
    background-color: var(--app-primary-color) !important;
}

.navbar-nav > .user-menu > .dropdown-menu > .user-body a:first-child {
    margin-bottom: 10px;
}

.bi {
    vertical-align: middle;
}
