<div class="text-end mb-2">
    <a href="{% url create_url_name %}" class="btn btn-outline-primary">
        <i class="bi bi-file-earmark-plus-fill me-2"></i>{{ create_text|default:'Nuevo' }}
    </a>
</div>
